AutocryptHeaders

Struct AutocryptHeaders 

pub struct AutocryptHeaders {
    pub from: Option<String>,
    pub headers: Vec<AutocryptHeader>,
}
A set of parsed Autocrypt headers.

Fields

from: Option<String>

The value in the from header.

headers: Vec<AutocryptHeader>

Any autocrypt headers.

Implementations

Source

impl AutocryptHeaders

pub fn from_bytes(data: &[u8]) -> Result<Self>

Parses an autocrypt header.

data should be all of a mail’s headers.

pub fn from_file<P: AsRef<Path>>(path: P) -> Result<Self>

Parses an autocrypt header.

path should name a file containing a single mail. If the file is in mbox format, then only the first mail is considered.

pub fn from_reader<R: Read>(reader: R) -> Result<Self>

Parses an autocrypt header.

reader contain a single mail. If it contains multiple emails, then only the first mail is considered.

pub fn from_buffered_reader<R, C>(reader: R) -> Result<Self>
where R: BufferedReader<C>, C: Debug + Send + Sync,

Parses an autocrypt header.

reader should be all of a mail’s headers.